==> gunfollower-0.1.0.crate: gunfollower-0.1.0/README.md <==
![Gunfollower Banner](assets/banner.png)

![release](https://img.shields.io/github/v/release/DarthBenro008/gunfollower)
![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/DarthBenro008/gunfollower/CrossPlatformBuild/master)
![rust-version](https://img.shields.io/badge/rust-v1.5.2-green)
[![GitHub License](https://img.shields.io/github/license/aryan9600/cowin-notifier)](https://github.com/DarthBenro008/gunfollower/blob/master/LICENSE)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](https://github.com/DarthBenro008/gunfollower/issues/new/choose)

> A CLI written in rust to check who follows and unfollows you on GitHub

# G-unfollower

A simple CLI that tell watches and let's you know if anyone has followed or unfollowed you recently with some cool caching mechanism.

![carbon](assets/carbon.png)

## Installation

### Using Cargo

You can install gunfollower from Cargo

```bash
cargo install gunfollower
```

### Manual Installation

You can also download the binary and install it manually.

- Go to [releases page](https://github.com/DarthBenro008/gunfollower/releases) and grab the latest release of rChore.
- Download the latest release of rChore specific to your OS.
- If you are on Linux/MacOS, make sure you move the binary to somewhere in your `$PATH` (e.g. `/usr/local/bin`).

## Architecture

![GunfollowerArch](assets/arch.png)


## 🤝 Contributions

- Feel Free to Open a PR/Issue for any feature or bug(s).
- Make sure you follow the [community guidelines](https://docs.github.com/en/github/site-policy/github-community-guidelines).
- Feel free to open an issue to ask a question/discuss anything about G-unfollower.
- Have a feature request? Open an Issue!

## ⚖ License

Copyright 2021 Hemanth Krishna

Licensed under MIT License : https://opensource.org/licenses/MIT

<p align="center">Made with ❤ and a single cup of coffee</p>

==> gunfollower-0.1.4.crate: gunfollower-0.1.4/README.md <==
![Gunfollower Banner](assets/banner.png)

![release](https://img.shields.io/github/v/release/DarthBenro008/gunfollower)
![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/DarthBenro008/gunfollower/CrossPlatformBuild/master)
![rust-version](https://img.shields.io/badge/rust-v1.5.2-green)
[![GitHub License](https://img.shields.io/github/license/aryan9600/cowin-notifier)](https://github.com/DarthBenro008/gunfollower/blob/master/LICENSE)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](https://github.com/DarthBenro008/gunfollower/issues/new/choose)

> A CLI written in rust to check who follows and unfollows you on GitHub

# G-unfollower

A simple CLI that tell watches and let's you know if anyone has followed or unfollowed you recently with some cool caching mechanism.

![carbon](assets/carbon.png)

## Installation

### Using Homebrew

```bash
brew tap DarthBenro008/gunfollower
brew install gunfollower
```

### Using Cargo

You can install gunfollower from Cargo

```bash
cargo install gunfollower
```

### Manual Installation

You can also download the binary and install it manually.

- Go to [releases page](https://github.com/DarthBenro008/gunfollower/releases) and grab the latest release of gunfollower.
- Download the latest release of gunfollower specific to your OS.
- If you are on Linux/MacOS, make sure you move the binary to somewhere in your `$PATH` (e.g. `/usr/local/bin`).

## Architecture

![GunfollowerArch](assets/arch.png)


## 🤝 Contributions

- Feel Free to Open a PR/Issue for any feature or bug(s).
- Make sure you follow the [community guidelines](https://docs.github.com/en/github/site-policy/github-community-guidelines).
- Feel free to open an issue to ask a question/discuss anything about G-unfollower.
- Have a feature request? Open an Issue!

## ⚖ License

Copyright 2021 Hemanth Krishna

Licensed under MIT License : https://opensource.org/licenses/MIT

<p align="center">Made with ❤ and a single cup of coffee</p>
